@@ -3,7 +3,7 @@
 
 int failures = 0;
 
-int run_suite(void (*suite)()) {
+int run_suite(void (*suite)(void)) {
     suite();
     return (failures > 0) ? 1 : 0;
 }
